@@ -77,6 +77,7 @@ class Handler:
         self.version = None
         self.repository = None
         self._recommended = False
+        self._auto_install = False
 
     def _package_defaults(self):
         '''Set fallback name/description/freeness from package.'''
@@ -165,6 +166,23 @@ class Handler:
         else:
             raise NotImplementedError, 'subclasses need to implement this'
 
+    def auto_install(self):
+        '''Return if the handler should be automatically installed.
+
+        This can be done by hardcoding self._auto_install = True, but the
+        recommended approach is to create a flag file
+        <handler_dir>/autoinstall.d/<driver id>, because that is easier to
+        customize.
+        '''
+        if self._auto_install:
+            return True
+
+        # check autoinstall.d/ flag
+        if os.path.exists(os.path.join(OSLib.inst.handler_dir, 'autoinstall.d', self.id())):
+            return True
+
+        return False
+
     def enabled(self):
         '''Return if the handler is enabled.
         
