@@ -170,6 +170,7 @@ class AbstractUI(dbus.service.Object):
         # this is used when one version of a driver is recommended over others
         self.string_recommended = self._('Recommended')
         self.string_license_dialog_title = self._('License Text for Device Driver')
+        self.string_install_drivers = self._('Install Drivers')
 
     def main_window_title(self):
         '''Return an appropriate translated window title.
@@ -178,9 +179,9 @@ class AbstractUI(dbus.service.Object):
         free drivers, only restricted ones, etc.).
         '''
         if self.argv_options.mode == 'nonfree':
-            return self._('Restricted Hardware Drivers')
+            return self._('Restricted Additional Drivers')
         else:
-            return self._('Hardware Drivers')
+            return self._('Additional Drivers')
 
     def main_window_text(self):
         '''Return a tuple (heading, subtext) of main window texts.
@@ -343,6 +344,9 @@ class AbstractUI(dbus.service.Object):
         parser.add_option ('-l', '--list', action='store_true',
                 dest='list', default=False,
                 help=self._('List available drivers and their status.'))
+        parser.add_option ('-a', '--auto-install', action='store_true',
+                dest='auto_install', default=False,
+                help=self._('Enable drivers that can be automatically installed.'))
         parser.add_option ('--hardware-ids', action='store_true',
                 dest='list_hwids', default=False,
                 help=self._('List hardware identifiers from this system.'))
@@ -423,6 +427,16 @@ class AbstractUI(dbus.service.Object):
             else:
                 return 1
 
+        elif self.argv_options.auto_install:
+            ret = 0
+            for h_id in self.backend().available(self.argv_options.mode):
+                i = self.backend().handler_info(h_id)
+                if bool(i['auto_install']) and not bool(i['enabled']):
+                    if not self.set_handler_enable(i['id'], 'enable',
+                        self.argv_options.confirm, False):
+                        ret = 1
+            return ret
+
         # start the UI
         self.ui_show_main()
         res = self.ui_main_loop()
@@ -434,11 +448,12 @@ class AbstractUI(dbus.service.Object):
 
         for h_id in self.backend().available(self.argv_options.mode):
             i = self.backend().handler_info(h_id)
-            print '%s - %s (%s, %s, %s)' % (
+            print '%s - %s (%s, %s, %s)%s' % (
                 h_id, i['name'],
                 bool(i['free']) and self.string_free or self.string_restricted,
                 bool(i['enabled']) and self.string_enabled or self.string_disabled,
-                bool(i['used']) and self.string_in_use or self.string_not_in_use)
+                bool(i['used']) and self.string_in_use or self.string_not_in_use,
+                bool(i['auto_install']) and ' [auto-install]' or '')
 
     def list_hwids(self):
         '''Print a list of available handlers and their status to stdout.'''
@@ -451,6 +466,15 @@ class AbstractUI(dbus.service.Object):
         
         Return True if any new driver is available which is not yet enabled.
         '''
+        # if the user is running Jockey with package installation or another
+        # long-running task in parallel, the automatic --check invocation will
+        # time out on this.
+        try:
+            convert_dbus_exceptions(self.backend)
+        except Exception, e:
+            print >> sys.stderr, 'Cannot connect to backend, is it busy?\n', e
+            return False
+
         try:
             (new_used, new_avail) = convert_dbus_exceptions(
                     self.backend().new_used_available, self.argv_options.mode)
@@ -785,22 +809,28 @@ class AbstractUI(dbus.service.Object):
         if self._dbus_iface.has_repositories():
             return
 
-        success = False
-        try:
-            self._repository_progress_shown = False
-            success = convert_dbus_exceptions(dbus_sync_call_signal_wrapper,
-                    self._dbus_iface, 'update_repository_indexes',
-                    {'repository_update_progress':
-                        self._repository_progress_handler})
-        finally:
-            if self._repository_progress_shown:
-                self.ui_progress_finish()
+        if self.have_ui:
+            success = False
+            try:
+                self._repository_progress_shown = False
+                success = convert_dbus_exceptions(dbus_sync_call_signal_wrapper,
+                        self._dbus_iface, 'update_repository_indexes',
+                        {'repository_update_progress':
+                            self._repository_progress_handler})
+            finally:
+                if self._repository_progress_shown:
+                    self.ui_progress_finish()
+
+            # check success
+            if not success:
+                self.error_message('', self._(
+                    'Downloading package indexes failed, please check your network status. '
+                    'Most drivers will not be available.'))
+        else:
+            # This happens when running in --check mode. We do not particularly
+            # care about success here.
+            convert_dbus_exceptions(self._dbus_iface.update_repository_indexes)
 
-        # check success
-        if not success:
-            self.error_message('', self._(
-    'Downloading package indexes failed, please check your network status. '
-    'Most drivers will not be available.'))
 
     #
     # Session D-BUS server methods
