@@ -18,7 +18,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-import unittest, sys, os.path, re, subprocess
+import unittest, sys, os.path, re, subprocess, shutil
 
 from jockey.oslib import OSLib
 import jockey.handlers, jockey.backend
@@ -26,6 +26,13 @@ from jockey.xorg_driver import XorgDriverHandler
 
 import sandbox
 
+class TestAutoInstallHandler(jockey.handlers.Handler):
+
+    def __init__(self, backend, name):
+        jockey.handlers.Handler.__init__(self, backend, name, 
+            'hardcoded auto-install handler')
+        self._auto_install = True
+
 class TestFirmwareHandler(jockey.handlers.FirmwareHandler):
 
     def __init__(self, backend, free=False):
@@ -76,6 +83,9 @@ class HandlerTest(sandbox.LogTestCase):
         OSLib.inst.reset_packages()
         OSLib.inst._make_proc_modules()
         jockey.handlers.KernelModuleHandler.read_loaded_modules()
+        auto_d = os.path.join(OSLib.inst.handler_dir, 'autoinstall.d')
+        if os.path.isdir(auto_d):
+            shutil.rmtree(auto_d)
 
     def test_basic(self):
         '''abstract Handler'''
@@ -977,3 +987,22 @@ EndSection
         self.assertEqual(h.rationale(), None)
         self.failIf(h.changed())
         self.assertEqual(h.can_change(), None)
+
+    def test_auto_install_hardcoded(self):
+        '''Handler auto-installed with hardcoded flag'''
+
+        h = jockey.handlers.Handler(self.backend, 'autotest')
+        self.assertEqual(h.auto_install(), False)
+        h = TestAutoInstallHandler(self.backend, 'autotest')
+        self.assertEqual(h.auto_install(), True)
+
+    def test_auto_install_flagfile(self):
+        '''Handler auto-installed with autoinstall.d/ file'''
+
+        d = os.path.join(OSLib.inst.handler_dir, 'autoinstall.d')
+        os.mkdir(d)
+        f = open(os.path.join(d, 'Handler:autotest'), 'w')
+        f.close()
+        h = jockey.handlers.Handler(self.backend, 'autotest')
+        self.assertEqual(h.auto_install(), True)
+
