@@ -1349,6 +1349,17 @@ class LessDullMod(KernelModuleHandler):
             description='Test suite: custom handler for dullstd (ignored kmod)')
 '''
 
+h_auto_install_mod = '''
+from jockey.handlers import KernelModuleHandler
+class AutoInstallHandler(KernelModuleHandler):
+    def __init__(self, ui):
+        KernelModuleHandler.__init__(self, ui, 'vanilla',
+            description='Test suite: automatically installed handler')
+        self._auto_install = True
+    def available(self):
+        return True
+'''
+
 #-------------------------------------------------------------------#
 # other globals
 
