@@ -910,3 +910,27 @@ class UITest(sandbox.LogTestCase):
         self.assertEqual(ui.hwid_to_display_string('printer_deviceid:MDL:InkShot 12;CMD:GDI;MFG:PH'), 
             'PH InkShot 12')
 
+    def test_check_auto_install(self):
+        '''calling with --auto-install'''
+
+        open (os.path.join(OSLib.inst.handler_dir, 'h.py'), 'w').write(
+            sandbox.h_auto_install_mod)
+
+        ui = sandbox.TestUI()
+        for h in ui.backend().available():
+            if ui.backend().handler_info(h)['enabled']:
+                ui.backend().set_enabled(h, False)
+        self.assertEqual(ui.run(), 0)
+        self.stop_capture()
+
+        sys.argv = ['ui-test', '--auto-install']
+        ui = sandbox.TestUI()
+        self.assertEqual(ui.run(), 0)
+
+        for h in ui.backend().available():
+            enabled = jockey.ui.bool(ui.backend().handler_info(h)['enabled'])
+            if h == 'kmod:vanilla':
+                self.assert_(enabled)
+            else:
+                self.assert_(not enabled, '%s shouldn\'t be enabled' % h)
+
